@@ -16,6 +16,7 @@ import re
 # import os #, sys
 import numpy as np
 from .parsing_tools import get_timecol, is_time, get_type, timestamp_to_seconds
+from .patches import fix_timecols
 
 # import warnings # actually not that useful, as you loose information about
 # when in the running of the code the problem appeared.
@@ -205,6 +206,7 @@ def synchronize(
 
     for nd, dataset in enumerate(datasets):
         dataset["combining_number"] = nd
+        fix_timecols(dataset)  # patch
         if "data_cols" not in dataset or len(dataset["data_cols"]) == 0:
             print(dataset["title"] + " is empty")
             hasdata[nd] = False
@@ -502,8 +504,8 @@ def synchronize(
                 # timecol will have been processed first or not...
                 except KeyError:
                     print(
-                        "WARNING: {col} should have timecol {timecol} but this is "
-                        + +f" not in dataset. Not adding {col} to the combined dataset."
+                        f"WARNING: {col} should have timecol {timecol} but this is "
+                        + f"not in dataset. Not adding {col} to the combined dataset."
                     )
                     continue
                 if (
@@ -519,7 +521,7 @@ def synchronize(
                                 + f"\ncombined_data['data_cols'] = {combined_data['data_cols']}"
                                 + f"\nl1 = {l1}\nl0 = {l0}"
                             )  # debugging DEBUGGING!
-                            from matplotlib import pyplot as plt
+                            from matplotlibc import pyplot as plt
 
                             fig, ax = plt.subplots()
                             ax.plot(dataset[timecol], dataset[col], "k")
@@ -766,6 +768,7 @@ def purge_column(dataset, col, purge=True, verbose=True):
 def cut_dataset(
     dataset_0,
     tspan=None,
+    t_edge=None,
     tspan_0=None,
     time_masks=None,
     # if I directly write time_masks = {} here, it saves old values...
@@ -785,7 +788,9 @@ def cut_dataset(
     dataset = dataset_0.copy()
     dataset["data_cols"] = dataset["data_cols"].copy()
     if tspan is None and tspan_0 is None:
-        return dataset
+        tspan = dataset["tspan"]
+        if t_edge is None:
+            t_edge = 120
     if time_masks is None:
         time_masks = {}
     # print('time_masks = ' + str(time_masks)) # debugging
@@ -794,6 +799,9 @@ def cut_dataset(
         t0 = dataset["tstamp"]
         tspan = [tspan_0[0] - t0, tspan_0[-1] - t0]
 
+    if t_edge is not None:
+        tspan = [tspan[0] - t_edge, tspan[-1] + t_edge]
+
     if verbose:
         print("cutting according to tspan = " + str(tspan))
     data_cols = dataset["data_cols"].copy()
