@@ -502,7 +502,7 @@ def get_signal(
     endpoints=5,
     fillcolor=None,
     unit="A",
-    verbose=True,
+    verbose=False,
     override=False,
     plotit=False,
     ax="new",
@@ -515,7 +515,7 @@ def get_signal(
     """
 
     if verbose:
-        print("geting signal for " + mass)
+        print("getting signal for " + mass)
 
     xcol, ycol = get_cols_for_mass(mass, MS_data)
     x = MS_data[xcol]
@@ -541,7 +541,7 @@ def get_signal(
         except KeyError:
             print("WARNING: no tspan available to get_signal()! using tspan='all'")
             tspan = "all"
-    if not tspan == "all":
+    if not (isinstance(tspan, str) and tspan == "all"):
         try:
             x, y = cut(x, y, tspan, override=override)
         except TypeError:
