@@ -16,7 +16,7 @@ from .EC import sync_metadata, make_selector, select_cycles
 from .Data_Importing import load_from_file
 from .Combining import synchronize, cut_dataset, sort_time, get_timecol, timeshift
 from .Plotting import plot_experiment, plot_vs_potential, plot_flux, plot_signal
-from .EC import correct_ohmic_drop, CV_difference
+from .EC import correct_ohmic_drop, CV_difference, get_capacitance
 from .Quantification import get_current, get_signal, get_potential
 from .Calibration import calibration_curve, point_calibration, chip_calibration
 
@@ -110,7 +110,8 @@ class Dataset:
             self.data = synchronize(datas, verbose=verbose)
         elif file_path is not None:
             self.folder, self.file = os.path.split(file_path)
-            print(file_path)  # debugging
+            if self.verbose:
+                print(f"loading from {file_path}")  # debugging
             # ^ ...or just one data file
             self.data = get_data_from_file(file_path, data_type=data_type)
         elif folder is not None:
@@ -383,7 +384,8 @@ class Dataset:
                 for col in self.data_cols
                 if (col[0] == "M" and col[-2:] == "-y")
             ]
-        print("masses = " + str(masses))  # debugging
+        if self.verbose:
+            print("masses = " + str(masses))  # debugging
 
         if hasattr(self, "mass_bgs"):
             mass_bgs = self.mass_bgs
@@ -413,34 +415,53 @@ class Dataset:
                 print("adding background back onto " + mass)  # debugging
                 self.data[mass + "-y"] += y_bg
 
-    def cut(self, tspan=None, cycles=None, verbose=True, **kwargs):
-        if tspan is not None:
-            new_data = cut_dataset(self.data, tspan=tspan, **kwargs)
+    def cut(self, tspan=None, t_edge=None, verbose=True, **kwargs):
+        """Return a dataset containing part of the this dataset.
+
+        This can be done either with a tspan (uses EC_MS.cut_dataset) or
+        cycles (uses EC_MS.select_cycles).
+        The default behavior (no arguments) is that of cut_dataset. I.e.,
+        cut the according to self.data["tspan"] buffered with t_edge=120
+
+        Args:
+            tspan: [t_start, t_finish] defining the part of the dataset to keep
+            t_edge: a buffer time to include before and after tspan
+            verbose: whether to print a lot of output to the terminal
+            **kwargs: If a key in ["cycle_number", "selector", "loop_number",
+                "file_number", "cycle", "sweep"] is given, call select_cycles
+                with that key as cycle_str. tspan and t_edge are ignored.
+                Additional key-word arguments passed on either to
+                cut_dataset or select_cycles
+
+        Returns a new dataset, cut in time as requested.
+        """
+        for key in [
+            "cycle_number",
+            "selector",
+            "loop_number",
+            "file_number",
+            "cycle",
+            "sweep",
+        ]:
+            # should add self.sel_str, but that would require major changes
+            if key in kwargs:
+                cycles = kwargs.pop(key)
+                new_data = select_cycles(
+                    self.data, cycles=cycles, cycle_str=key, verbose=verbose, **kwargs,
+                )
+                break
         else:
-            for key in [
-                "cycle number",
-                "selector",
-                "loop number",
-                "file number",
-                "cycle",
-                "sweep",
-            ]:
-                # should add self.sel_str, but that would require major changes
-                if key in kwargs:
-                    cycles = kwargs.pop(key)
-                    new_data = select_cycles(
-                        self.data,
-                        cycles=cycles,
-                        cycle_str=key,
-                        verbose=verbose,
-                        **kwargs,
-                    )
+            new_data = cut_dataset(self.data, tspan=tspan, t_edge=t_edge, **kwargs)
+
         new_dataset = Dataset(new_data)
         for attr in metadata_items:
             if hasattr(self, attr):
                 setattr(new_dataset, attr, getattr(self, attr))
         return new_dataset
 
+    def as_cv(self):
+        return CyclicVoltammagram(self)
+
 
 class CyclicVoltammagram(Dataset):
     """
@@ -679,6 +700,12 @@ class CyclicVoltammagram(Dataset):
             return np.mean(scan_rate[mask])
         return self.scan_rate
 
+    def get_capacitance(self, V_DL=None, V_str=None, J_str=None, t_i=None, out=None):
+        """Return capacitance in F/cm^2 (geometric)"""
+        return get_capacitance(
+            self.data, V_DL=V_DL, V_str=V_str, J_str=J_str, t_i=t_i, out=out
+        )
+
     def make_scan_rate(self, min_sweep_points=10):
         """
         calculates scan rate in mV/s - negative for cathodic, positive for anodic.
@@ -763,17 +790,33 @@ class CyclicVoltammagram(Dataset):
             t_str = self.t_str
         except AttributeError:
             t_str = "time/s"
+        try:
+            E_str = self.E_str
+        except AttributeError:
+            E_str = "Ewe/V"
+        try:
+            I_str = self.I_str
+        except AttributeError:
+            I_str = "I/mA"
         try:
             V_str = self.V_str
         except AttributeError:
-            V_str = "Ewe/V"
+            V_str = E_str
         try:
             J_str = self.J_str
         except AttributeError:
-            J_str = "I/mA"
+            J_str = I_str
 
         diff = Dataset(
-            {"data_cols": set(), "V_str": V_str, "t_str": t_str, "J_str": J_str,}
+            {
+                "data_cols": set(),
+                "timecols": {},
+                "t_str": t_str,
+                "V_str": V_str,
+                "J_str": J_str,
+                "E_str": E_str,
+                "I_str": I_str,
+            }
         )
         debugging = False
         if debugging:
@@ -819,8 +862,12 @@ class CyclicVoltammagram(Dataset):
                     x1, y1_i = data1[tcol], data1[col]
                     x2, y2_i = data2[tcol], data2[col]
 
-                    y1 = np.interp(t1, x1, y1_i)
-                    y2 = np.interp(t2, x2, y2_i)
+                    try:
+                        y1 = np.interp(t1, x1, y1_i)
+                        y2 = np.interp(t2, x2, y2_i)
+                    except ValueError as e:
+                        print(f"skipping column {col} due to ValueError {e}")
+                        continue
 
                     y_diff = y1 - y2
 
