@@ -35,7 +35,8 @@ class Extraction(Dataset):
         A_el=None,
         t_bg=None,
         calibration=None,
-        calibration_file="20A25_sniffer.json",
+        mdict=None,
+        calibration_file=None,  # "20A25_sniffer.json",
         electrolyte="16O",
         film="18O",
         element="Pt",
@@ -48,16 +49,28 @@ class Extraction(Dataset):
             name = f"extraction {element}{film} in {electrolyte}"
         self.name = name
         self.calibration_file = calibration_file
+        if (not calibration) and calibration_file and not mdict:
+            print(f"requested calibration_file = {calibration_file}")
+            raise NotImplementedError(
+                "proper calibration is not implemented in EC_MS. "
+                "You have to import the calibration externally. "
+                "An EC_MS mdict should also work.\n"
+                "...The functionality should come soon to ixdat."
+            )
         self.calibration = calibration
-        self.mdict = get_EC_MS_mdict(calibration)
+        if calibration and not mdict:
+            mdict = get_EC_MS_mdict(calibration)
+        self.mdict = mdict
         # Later we will just directly use the siQuant mdict!
         self.data_file = data_file
         self.data_files = data_files
         self.data_dir = data_dir
         if dataset is None:
             if data_file is not None:  # <-- load one data file
-                if os.sep not in data_file:
+                if os.sep not in str(data_file):
                     path_to_data = os.path.join(data_dir, data_file)
+                else:
+                    path_to_data = data_file
                 dataset = Dataset(path_to_data)
             elif data_files is not None:  # <-- synchronize multiple datasets!
                 dataset = Dataset()
@@ -67,6 +80,9 @@ class Extraction(Dataset):
                     dataset = dataset + Dataset(path_to_data)
         self.dataset = dataset
         self.data = dataset.data
+        self.verbose = self.dataset.verbose
+        print(f"Extraction.__init__: type(dataset) = f{type(dataset)}")
+        self.data = dataset.data
         self.RE_vs_RHE = RE_vs_RHE
         self.A_el = A_el
         if RE_vs_RHE is not None or A_el is not None:
@@ -127,34 +143,62 @@ class Extraction(Dataset):
     def plot_experiment(self, *args, **kwargs):
         """
         Just adds to the plot_experiment of the Dataset class that it uses
-        the calibration and tspan_experiment by default
+        the calibration and tspan_experiment by default.
+        Molecules can be given as str and the Extraction tries to look them
+        up in its calibration.
         """
-        to_plot = []
-        to_plot_0 = None
+        to_plot = []  # this will be either mols or masses to plot
+        to_plot_0 = None  # first we see if the function caller told us what to plot
         if len(args) > 0:
-            to_plot_0 = args[0]
-        elif "mols" in kwargs:
+            to_plot_0 = args[0]  # first positional argument should be mols or masses!
+        elif "mols" in kwargs:  # ... but mols can also be given as a kwarg
             to_plot_0 = kwargs["mols"]
-        if to_plot_0 is not None:
+        elif "masses" in kwargs:  # ... and so can masses
+            pass  # but then we don't actually need to do anything to it
+
+        if to_plot_0:
+            # now we go through and put the requested calibrated objects in to_plot
             for i, thing in enumerate(to_plot_0):
-                if type(thing) is str and thing in self.mdict:
+                print(f"thing to plot = {thing}")  # debugging
+                if isinstance(thing, str) and thing in self.mdict:
+                    # excellent! then we've got the name of a calibrated molecule.
                     to_plot += [self.mdict[thing]]
+                elif isinstance(thing, list) or isinstance(thing, tuple):
+                    # ^ this will be the case if they ask for mols left and mols right
+                    to_plot += [[]]  # we need to mirror the list in to_plot
+                    for subthing in thing:
+                        print(f"subthing to plot = {subthing}")  # debugging
+                        if isinstance(subthing, str) and subthing in self.mdict:
+                            # excellent! then we've got the name of a calibrated molecule.
+                            to_plot[-1] += [self.mdict[subthing]]
+                        else:
+                            # then we assume they know what they're doing.
+                            to_plot[-1] += [subthing]
                 else:
+                    # then we assume they know what they're doing.
                     to_plot += [thing]
         elif "masses" not in kwargs:
+            # okay, so this is actually the case if they don't ask for anything to plot
+            #   and then by default we try to plot everything in the calibration
             to_plot = self.mdict
 
         # print(f"to_plot_0 = {to_plot_0}") # debugging
         # print(f"to_plot = {to_plot}") # debugging
 
         if len(args) > 0:
+            # then we overwrite to_plot_0, which is args[0], with to_plot:
             args[0] = to_plot
         elif "mols" in kwargs or "masses" not in kwargs:
+            # this is the case if they asked for mols or didn't ask for anything.
+            #   and then we've generated the calibrated plotted list:
             kwargs["mols"] = to_plot
 
         if len(args) < 2 and "tspan" not in kwargs:
+            # ah, yes, we use the Experiment tspan by default instead of the Dataset tspan:
             kwargs.update(tspan=self.tspan_experiment)
 
+        # and now we're ready to call plot_experiment via Dataset.plot_experiment!
+
         return super(Extraction, self).plot_experiment(*args, **kwargs)
 
     def get_alpha(self, tspan=None, t_bg=None, simple=True, ax="new"):
@@ -255,7 +299,7 @@ class Extraction(Dataset):
         return ratio
 
     def plot_exchange(
-        self, mol="O2", tspan=None, t_bg=None, axes="new", unit="pmol/s", **kwargs
+        self, mol="O2", tspan=None, t_bg=None, axes="new", unit=None, **kwargs
     ):
         if tspan is None or tspan == "experiment":
             tspan = self.tspan_experiment
@@ -266,6 +310,9 @@ class Extraction(Dataset):
         ratio = self.get_ratio()
         majors, minors = self.get_majors_and_minors(mol=mol)
 
+        unit_right = kwargs.get("unit_right", unit)
+        unit_left = kwargs.get("unit_left", unit)
+
         if axes == "new":
             axes = self.plot_experiment(
                 mols=[minors, majors],
@@ -279,42 +326,51 @@ class Extraction(Dataset):
         else:
             for molecule in minors:
                 self.plot_flux(
-                    molecule, ax=axes[0], tspan=tspan, unit=unit, logplot=False
+                    molecule, ax=axes[0], tspan=tspan, unit=unit_left, logplot=False
                 )
             for molecule in majors:
                 self.plot_flux(
-                    molecule, ax=axes[-1], tspan=tspan, unit=unit, logplot=False
+                    molecule, ax=axes[-1], tspan=tspan, unit=unit_right, logplot=False
                 )
 
+        unit_ratio = 1
+        if (
+            unit_left
+            and unit_right
+            and unit_left.startswith("p")
+            and unit_right.startswith("n")
+        ):
+            unit_ratio *= 1e3
+        axes_ratio = ratio * unit_ratio
         if True:  # highlight the labeled lattice oxygen evolution
-            x1, y1 = self.get_flux(majors[0], t_bg=t_bg, unit="pmol/s", tspan=tspan)
-            x2, y2 = self.get_flux(minors[0], t_bg=t_bg, unit="pmol/s", tspan=tspan)
+            x1, y1 = self.get_flux(majors[0], t_bg=t_bg, unit=unit_right, tspan=tspan)
+            x2, y2 = self.get_flux(minors[0], t_bg=t_bg, unit=unit_left, tspan=tspan)
             y2_interp = np.interp(x1, x2, y2)
             color_1 = minors[0].get_color()
             color_2 = majors[0].get_color()
             axes[0].fill_between(
                 x1,
-                y1 * ratio,
+                y1 * axes_ratio,
                 y2_interp,
                 color=color_1,
                 where=y2_interp > y1 * ratio,
-                alpha=0.5,
+                alpha=0.2,
             )
             axes[0].fill_between(
                 x1,
-                y1 * ratio,
+                y1 * axes_ratio,
                 y2_interp,
                 color=color_2,
                 where=y2_interp < y1 * ratio,
-                alpha=0.2,
+                alpha=0.1,
                 hatch="//",
             )
-        axes[-1].set_ylim([l / ratio for l in axes[0].get_ylim()])
+        axes[-1].set_ylim([l / axes_ratio for l in axes[0].get_ylim()])
 
         return axes
 
     def plot_extraction_vs_potential(
-        self, mol="CO2", tspan=None, unit="pmol/s", ax="new", reverse=True
+        self, mol="CO2", tspan=None, unit=None, ax="new", reverse=True
     ):
         if tspan is None:
             tspan = self.tspan_extraction
@@ -388,7 +444,7 @@ def get_EC_MS_mdict(calibration, mols=None, get_cal_mat=True):
             mols = mols.union(calibration.mdict)  # adds mdict's keys to the set mols
     for mol in mols:
         print(f"geting EC_MS molecule {mol} from calibration")
-        molecule = calibration.get_molecule(mol, withQ=get_cal_mat)
+        molecule = calibration.molecule(mol, with_Q=get_cal_mat)
         if mol in calibration.real_names:
             mol_name = calibration.real_names[mol]
         else:
@@ -414,9 +470,9 @@ def get_EC_MS_mdict(calibration, mols=None, get_cal_mat=True):
 
 
 def parse_isotope(isotope):
-    if isotope in ["18O", "O18"]:
+    if isotope in ["18O", "O18", "18", 18]:
         return "18O"
-    elif isotope in ["16O", "O16"]:
+    elif isotope in ["16O", "O16", "16", 16]:
         return "16O"
     else:
         return isotope
